# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018, 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from pyspark.sql import SparkSession

def logisticLoss(dataWithPredictions):
    """
    Args:
        dataWithPredictions: probabilities computed by the LogisticRegression predict_proba() function
    Returns:
        double: logistic loss computed by the logistic regression predicted probabilities
    """
    ss = SparkSession.builder.getOrCreate()
    return ss._jvm.com.ibm.snap.ml.Metrics.logisticLoss(dataWithPredictions)


def meanSquaredError(dataWithPredictions):
    """
    Args:
        dataWithPredictions: linear regression predictions, predicted by the RidgeRegression predict() function
    Returns:
        double: mean squared error computed based on the provided dataWithPredictions parameter
    """
    ss = SparkSession.builder.getOrCreate()
    return ss._jvm.com.ibm.snap.ml.Metrics.mean_squared_error(dataWithPredictions)


def accuracy(dataWithPredictions):
    """
    Args:
        dataWithPredictions: binary predictions computed by the LogisticRegression or SupportVectorMachine predict() function
    Returns:
        double: accuracy computed based on the binary predictions of a classifier (LogisticRegression, SupportVectorMachines)
    """
    ss = SparkSession.builder.getOrCreate()

    return ss._jvm.com.ibm.snap.ml.Metrics.accuracy(dataWithPredictions)

def precision(dataWithPredictions):
    """
    Args:
        dataWithPredictions: binary predictions computed by the LogisticRegression or SupportVectorMachine predict() function
    Returns:
        double: precision metric (TP/(TP+FP)), computed based on the binary predictions of a classifier (LogisticRegression, SupportVectorMachines)
    """
    ss = SparkSession.builder.getOrCreate()
    return ss._jvm.com.ibm.snap.ml.Metrics.precision(dataWithPredictions)

def recall(dataWithPredictions):
    """
    Args:
        dataWithPredictions: binary predictions computed by the LogisticRegression or SupportVectorMachine predict() function
    Returns:
        double: recall metric (TP/(TP+FN)), computed based on the binary predictions of a classifier (LogisticRegression, SupportVectorMachines)
    """
    ss = SparkSession.builder.getOrCreate()
    return ss._jvm.com.ibm.snap.ml.Metrics.recall(dataWithPredictions)

def f1score(dataWithPredictions):
    """
    Args:
        dataWithPredictions: binary predictions computed by the LogisticRegression or SupportVectorMachine predict() function
    Returns:
        double: f1score metric (2*(precision*recall)/(precision+recall)), computed based on the binary predictions of a classifier (LogisticRegression, SupportVectorMachines)
    """
    ss = SparkSession.builder.getOrCreate()
    precision = ss._jvm.com.ibm.snap.ml.Metrics.precision(dataWithPredictions)
    recall = ss._jvm.com.ibm.snap.ml.Metrics.recall(dataWithPredictions)
    f1score = 2*((precision*recall)/(precision + recall))

    return f1score
