# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from __future__ import print_function
from pyspark import SparkConf, SparkContext
from snap_ml_spark import DatasetReader
from snap_ml_spark import LinearRegression
from snap_ml_spark.Metrics import meanSquaredError, accuracy
import os
import argparse
import time

defaultPath = os.getcwd()
CLI=argparse.ArgumentParser()
CLI.add_argument(
    "--use_gpu",
    action = 'store_true',
    default=False
)
CLI.add_argument(
   "--data_path",
   type=str,
   default=defaultPath
)
CLI.add_argument(
   "--num_partitions",
   type=int,
   default= 2
)
CLI.add_argument(
   "--use_balanced_class_weights",
   action = 'store_true',
   default=False
)
args = CLI.parse_args()
if args.use_balanced_class_weights:
  class_weights = "balanced"
else:
  class_weights = None

# Set your own master (e.g 'spark://node1.ibm.com:7077') or use 'local'
# Configure Spark (2 executors, local standalone mode)
# If one wants to run spark on a cluster, use your own spark configuration (set master , appName, etc...)
conf = SparkConf()\
.set("spark.default.parallelism",args.num_partitions)\
.set("spark.cores.max",args.num_partitions)\
.setAppName("LinearRegressionExample")
# Create spark config
sc = SparkContext(conf=conf)

# disable spark INFO logging - comment out to enable
log4j = sc._jvm.org.apache.log4j
log4j.LogManager.getRootLogger().setLevel(log4j.Level.ERROR)

## Lasso Example

# Load training data (from libsvm format)
# Please use the absolute path of the file if you wish to run the example on a distributed mode
trainData_t = DatasetReader().setFormat("snap").load(args.data_path + "/data/small_sparse.snap.t")

# Load test data (from libsvm format)
# Please use the absolute path of the file if you wish to run the example on a distributed mode
testData = DatasetReader().setFormat("libsvm").load(args.data_path + "/data/small.libsvm")

# Create Linear regression (Lasso)
rr = LinearRegression(verbose=False, max_iter=20, dual=False, penalty='l1',
                      class_weights=class_weights, return_training_history='summary')

# Fit Linear regression model on training data
snapml_t0 = time.time()
final_trainCost = rr.fit(trainData_t)['train_obj']
snapml_time = time.time() - snapml_t0

print("Training Time = %.3f" % (snapml_time))
print("TrainCost = %f" % (final_trainCost))

# Perform inference on test data
pred = rr.predict(testData)

# Compute accuracy
mse = meanSquaredError(pred)

# Print off result
print("Lasso meanSquaredError = %.3f" % (mse))


## Ridge Regression Example

trainData = DatasetReader().setFormat("libsvm").load(args.data_path + "/data/small.libsvm")

# Create Linear regression (Ridge)
rr = LinearRegression(verbose=False, max_iter=20, dual=True, penalty='l2',
                      class_weights=class_weights, return_training_history='summary')

# Fit Linear regression model on training data
snapml_t0 = time.time()
final_trainCost = rr.fit(trainData)['train_obj']
snapml_time = time.time() - snapml_t0

print("Training Time = %.3f" % (snapml_time))
print("TrainCost = %f" % (final_trainCost))

# Perform inference on test data
pred = rr.predict(testData)

# Compute accuracy
mse = meanSquaredError(pred)

# Print off result
print("LinearRegression meanSquaredError = %.3f" % (mse))
